@@ -47,7 +47,11 @@ public:
     };
     Q_ENUM(LogLevelIds)
 
-    enum DateFormat { LongFormat = 0, ShortFormat, PreciseFormat };
+    enum DateFormat {
+        LongFormat = 0,
+        ShortFormat,
+        PreciseFormat
+    };
 
     QString formatDate(DateFormat format, const QDateTime &dateTime) const;
 
