@@ -334,22 +334,22 @@ static const QMap<ulong, QString> schedMap = {{0, QStringLiteral("SCHED_OTHER")}
 static const QMap<ulong, QString> openflagMap = {{0x0, QStringLiteral("O_RDONLY")},
                                                  {0x1, QStringLiteral("O_WRONLY")},
                                                  {0x2, QStringLiteral("O_RDWR")},
-                                                 {0x100, QStringLiteral("O_CREAT")},
-                                                 {0x200, QStringLiteral("O_EXCL")},
-                                                 {0x400, QStringLiteral("O_NOCTTY")},
-                                                 {0x1000, QStringLiteral("O_TRUNC")},
-                                                 {0x2000, QStringLiteral("O_APPEND")},
-                                                 {0x4000, QStringLiteral("O_NONBLOCK")},
-                                                 {0x10000, QStringLiteral("O_DSYNC")},
-                                                 {0x20000, QStringLiteral("O_ASYNC")},
-                                                 {0x40000, QStringLiteral("O_DIRECT")},
-                                                 {0x200000, QStringLiteral("O_DIRECTORY")},
-                                                 {0x400000, QStringLiteral("O_NOFOLLOW")},
-                                                 {0x1000000, QStringLiteral("O_NOATIME")},
-                                                 {0x2000000, QStringLiteral("O_CLOEXEC")},
-                                                 {0x4000000, QStringLiteral("O_SYNC")},
-                                                 {0x10000000, QStringLiteral("__O_PATH")},
-                                                 {0x20000000, QStringLiteral("__O_TMPFILE")}};
+                                                 {0x40, QStringLiteral("O_CREAT")},
+                                                 {0x80, QStringLiteral("O_EXCL")},
+                                                 {0x100, QStringLiteral("O_NOCTTY")},
+                                                 {0x200, QStringLiteral("O_TRUNC")},
+                                                 {0x400, QStringLiteral("O_APPEND")},
+                                                 {0x800, QStringLiteral("O_NONBLOCK")},
+                                                 {0x1000, QStringLiteral("O_DSYNC")},
+                                                 {0x2000, QStringLiteral("O_ASYNC")},
+                                                 {0x4000, QStringLiteral("O_DIRECT")},
+                                                 {0x10000, QStringLiteral("O_DIRECTORY")},
+                                                 {0x20000, QStringLiteral("O_NOFOLLOW")},
+                                                 {0x40000, QStringLiteral("O_NOATIME")},
+                                                 {0x80000, QStringLiteral("O_CLOEXEC")},
+                                                 {0x100000, QStringLiteral("__O_SYNC")},
+                                                 {0x200000, QStringLiteral("O_PATH")},
+                                                 {0x400000, QStringLiteral("__O_TMPFILE")}};
 
 static const QMap<ulong, QString> accessMap = {{0x1U, QStringLiteral("X_OK")}, {0x2U, QStringLiteral("W_OK")}, {0x4U, QStringLiteral("R_OK")}};
 
