@@ -6,9 +6,6 @@
 
 #pragma once
 
-#include <QList>
-#include <QStringList>
-
 #include "defaults.h"
 #include "genericConfiguration.h"
 #include "globals.h"
@@ -26,4 +23,3 @@ public:
     {
     }
 };
-
